penet_large: A penetrance matrix relating the phenotypes in 'dat_large' to...

penet_largeR Documentation

A penetrance matrix relating the phenotypes in dat_large to three genotypes

Description

A matrix relating the phenotypes of dat_large to the three unphased genotypes of a single biallelic, autosomal genetic locus. The element penet_large[i,j] is the conditional probability of the phenotypes (i.e. sex, aff and age) of the person in row i of dat_large, given that his or her genotype is j (here labelling the genotypes as ⁠1, 2, 3⁠, where genotype 2 is the heterozygous genotype).

Usage

penet_large

Format

A matrix with 10,002 rows (corresponding to persons) and 3 columns (corresponding to genotypes).

Simulated


clipp documentation built on Sept. 1, 2026, 5:07 p.m.